io: change the name of ReadAtSizer to SizedReaderAt

This is a proposal. The old name is pretty poor. The new one describes
it better and may be easier to remember. It does not start with Read,
though I think that inconsistency is worthwhile.

Reworded the comment a bit for clarity.

Change-Id: Icb4f9c663cc68958e0363d7ff78a0b29cc521f98
Reviewed-on: https://go-review.googlesource.com/21629
Reviewed-by: Andrew Gerrand <adg@golang.org>
Reviewed-by: Brad Fitzpatrick <bradfitz@golang.org>
diff --git a/src/io/io.go b/src/io/io.go
index 23401da..023473c 100644
--- a/src/io/io.go
+++ b/src/io/io.go
@@ -274,10 +274,11 @@
 	UnreadRune() error
 }
 
 // ReadAtSizer is the interface that groups the basic ReadAt and Size
 // methods, representing a sized data source that supports random
 // access by multiple concurrent goroutines.
-type ReadAtSizer interface {
+type SizedReaderAt interface {
 	ReaderAt
 	// Size reports the length of the data source in bytes.
 	Size() int64
@@ -274,10 +274,11 @@
 }
 
-// ReadAtSizer is the interface that groups the basic ReadAt and Size
-// methods, representing a sized data source that supports random
+// SizedReaderAt is the interface that groups the basic ReadAt method
+// with a Size method that reports the total size of the underlying
+// object. It represents a fixed-size data source that supports random
 // access by multiple concurrent goroutines.